@@ -11,7 +11,18 @@ import time
 import warnings
 import webbrowser
 from types import ModuleType
-from typing import TYPE_CHECKING, Any, AnyStr, Callable, Dict, List, Optional, Tuple
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    AnyStr,
+    Callable,
+    Dict,
+    Iterator,
+    List,
+    Optional,
+    Set,
+    Tuple,
+)
 
 import anyio
 import requests
@@ -34,7 +45,13 @@ from gradio.documentation import (
     document_component_api,
     set_documentation_group,
 )
-from gradio.utils import component_or_layout_class, delete_none
+from gradio.exceptions import DuplicateBlockError
+from gradio.utils import (
+    check_function_inputs_match,
+    component_or_layout_class,
+    delete_none,
+    get_cancel_function,
+)
 
 set_documentation_group("blocks")
 
@@ -62,18 +79,22 @@ class Block:
         """
         Adds self into appropriate BlockContext
         """
+        if Context.root_block is not None and self._id in Context.root_block.blocks:
+            raise DuplicateBlockError(
+                f"A block with id: {self._id} has already been rendered in the current Blocks."
+            )
         if Context.block is not None:
-            Context.block.children.append(self)
+            Context.block.add(self)
         if Context.root_block is not None:
             Context.root_block.blocks[self._id] = self
             if hasattr(self, "temp_dir"):
                 Context.root_block.temp_dirs.add(self.temp_dir)
+        return self
 
     def unrender(self):
         """
         Removes self from BlockContext if it has been rendered (otherwise does nothing).
-        Only deletes the first occurrence of self in BlockContext. Removes from the
-        layout and collection of Blocks, but does not delete any event triggers.
+        Removes self from the layout and collection of blocks, but does not delete any event triggers.
         """
         if Context.block is not None:
             try:
@@ -104,18 +125,21 @@ class Block:
     def set_event_trigger(
         self,
         event_name: str,
-        fn: Optional[Callable],
-        inputs: Optional[Component | List[Component]],
-        outputs: Optional[Component | List[Component]],
+        fn: Callable | None,
+        inputs: Component | List[Component] | Set[Component] | None,
+        outputs: Component | List[Component] | None,
         preprocess: bool = True,
         postprocess: bool = True,
         scroll_to_output: bool = False,
         show_progress: bool = True,
-        api_name: Optional[AnyStr] = None,
-        js: Optional[str] = None,
+        api_name: AnyStr | None = None,
+        js: str | None = None,
         no_target: bool = False,
-        queue: Optional[bool] = None,
-    ) -> None:
+        queue: bool | None = None,
+        batch: bool = False,
+        max_batch_size: int = 4,
+        cancels: List[int] | None = None,
+    ) -> Dict[str, Any]:
         """
         Adds an event to the component's dependencies.
         Parameters:
@@ -130,18 +154,40 @@ class Block:
             api_name: Defining this parameter exposes the endpoint in the api docs
             js: Optional frontend js method to run before running 'fn'. Input arguments for js method are values of 'inputs' and 'outputs', return should be a list of values for output components
             no_target: if True, sets "targets" to [], used for Blocks "load" event
+            batch: whether this function takes in a batch of inputs
+            max_batch_size: the maximum batch size to send to the function
+            cancels: a list of other events to cancel when this event is triggered. For example, setting cancels=[click_event] will cancel the click_event, where click_event is the return value of another components .click method.
         Returns: None
         """
         # Support for singular parameter
-        if inputs is None:
-            inputs = []
-        if outputs is None:
-            outputs = []
-        if not isinstance(inputs, list):
-            inputs = [inputs]
-        if not isinstance(outputs, list):
-            outputs = [outputs]
-        Context.root_block.fns.append(BlockFunction(fn, preprocess, postprocess))
+        if isinstance(inputs, set):
+            inputs_as_dict = True
+            inputs = sorted(inputs, key=lambda x: x._id)
+        else:
+            inputs_as_dict = False
+            if inputs is None:
+                inputs = []
+            elif not isinstance(inputs, list):
+                inputs = [inputs]
+
+        if isinstance(outputs, set):
+            outputs = sorted(outputs, key=lambda x: x._id)
+        else:
+            if outputs is None:
+                outputs = []
+            elif not isinstance(outputs, list):
+                outputs = [outputs]
+
+        if fn is not None:
+            check_function_inputs_match(fn, inputs, inputs_as_dict)
+
+        if Context.root_block is None:
+            raise AttributeError(
+                f"{event_name}() and other events can only be called within a Blocks context."
+            )
+        Context.root_block.fns.append(
+            BlockFunction(fn, inputs, outputs, preprocess, postprocess, inputs_as_dict)
+        )
         if api_name is not None:
             api_name_ = utils.append_unique_suffix(
                 api_name, [dep["api_name"] for dep in Context.root_block.dependencies]
@@ -162,6 +208,9 @@ class Block:
             "api_name": api_name,
             "scroll_to_output": scroll_to_output,
             "show_progress": show_progress,
+            "batch": batch,
+            "max_batch_size": max_batch_size,
+            "cancels": cancels or [],
         }
         if api_name is not None:
             dependency["documentation"] = [
@@ -175,6 +224,7 @@ class Block:
                 ],
             ]
         Context.root_block.dependencies.append(dependency)
+        return dependency
 
     def get_config(self):
         return {
@@ -210,6 +260,10 @@ class BlockContext(Block):
         Context.block = self
         return self
 
+    def add(self, child):
+        child.parent = self
+        self.children.append(child)
+
     def fill_expected_parents(self):
         children = []
         pseudo_parent = None
@@ -228,10 +282,12 @@ class BlockContext(Block):
                     children.append(pseudo_parent)
                     pseudo_parent.children = [child]
                     Context.root_block.blocks[pseudo_parent._id] = pseudo_parent
+                child.parent = pseudo_parent
         self.children = children
 
     def __exit__(self, *args):
-        self.fill_expected_parents()
+        if getattr(self, "allow_expected_parents", True):
+            self.fill_expected_parents()
         Context.block = self.parent
 
     def postprocess(self, y):
@@ -242,12 +298,23 @@ class BlockContext(Block):
 
 
 class BlockFunction:
-    def __init__(self, fn: Optional[Callable], preprocess: bool, postprocess: bool):
+    def __init__(
+        self,
+        fn: Optional[Callable],
+        inputs: List[Component],
+        outputs: List[Component],
+        preprocess: bool,
+        postprocess: bool,
+        inputs_as_dict: bool,
+    ):
         self.fn = fn
+        self.inputs = inputs
+        self.outputs = outputs
         self.preprocess = preprocess
         self.postprocess = postprocess
         self.total_runtime = 0
         self.total_runs = 0
+        self.inputs_as_dict = inputs_as_dict
 
     def __str__(self):
         return str(
@@ -317,23 +384,39 @@ def skip() -> dict:
     return update()
 
 
-def postprocess_update_dict(block: Block, update_dict: Dict):
+def postprocess_update_dict(block: Block, update_dict: Dict, postprocess: bool = True):
+    """
+    Converts a dictionary of updates into a format that can be sent to the frontend.
+    E.g. {"__type__": "generic_update", "value": "2", "interactive": False}
+    Into -> {"__type__": "update", "value": 2.0, "mode": "static"}
+
+    Parameters:
+        block: The Block that is being updated with this update dictionary.
+        update_dict: The original update dictionary
+        postprocess: Whether to postprocess the "value" key of the update dictionary.
+    """
     prediction_value = block.get_specific_update(update_dict)
     if prediction_value.get("value") is components._Keywords.NO_VALUE:
         prediction_value.pop("value")
     prediction_value = delete_none(prediction_value, skip_value=True)
-    if "value" in prediction_value:
+    if "value" in prediction_value and postprocess:
         prediction_value["value"] = block.postprocess(prediction_value["value"])
     return prediction_value
 
 
-def convert_update_dict_to_list(outputs_ids: List[int], predictions: Dict) -> List:
+def convert_component_dict_to_list(outputs_ids: List[int], predictions: Dict) -> List:
+    """
+    Converts a dictionary of component updates into a list of updates in the order of
+    the outputs_ids and including every output component.
+    E.g. {"textbox": "hello", "number": {"__type__": "generic_update", "value": "2"}}
+    Into -> ["hello", {"__type__": "generic_update"}, {"__type__": "generic_update", "value": "2"}]
+    """
     keys_are_blocks = [isinstance(key, Block) for key in predictions.keys()]
     if all(keys_are_blocks):
         reordered_predictions = [skip() for _ in outputs_ids]
         for component, value in predictions.items():
             if component._id not in outputs_ids:
-                return ValueError(
+                raise ValueError(
                     f"Returned component {component} not specified as output of function."
                 )
             output_index = outputs_ids.index(component._id)
@@ -378,7 +461,7 @@ class Blocks(BlockContext):
             btn.click(fn=update, inputs=inp, outputs=out)
 
         demo.launch()
-    Demos: blocks_hello, blocks_flipper, blocks_speech_text_sentiment, generate_english_german
+    Demos: blocks_hello, blocks_flipper, blocks_speech_text_sentiment, generate_english_german, sound_alert
     Guides: blocks_and_event_listeners, controlling_layout, state_in_blocks, custom_CSS_and_JS, custom_interpretations_with_blocks, using_blocks_like_functions
     """
 
@@ -408,6 +491,7 @@ class Blocks(BlockContext):
         self.share = False
         self.enable_queue = None
         self.max_threads = 40
+        self.show_error = True
         if css is not None and os.path.exists(css):
             with open(css) as css_file:
                 self.css = css_file.read()
@@ -433,8 +517,9 @@ class Blocks(BlockContext):
         self.share_url = None
         self.width = None
         self.height = None
+        self.api_open = True
 
-        self.ip_address = utils.get_local_ip_address()
+        self.ip_address = None
         self.is_space = True if os.getenv("SYSTEM") == "spaces" else False
         self.favicon_path = None
         self.auth = None
@@ -444,16 +529,17 @@ class Blocks(BlockContext):
         self.title = title
         self.show_api = True
 
-        data = {
-            "mode": self.mode,
-            "ip_address": self.ip_address,
-            "custom_css": self.css is not None,
-            "theme": self.theme,
-            "version": pkgutil.get_data(__name__, "version.txt")
-            .decode("ascii")
-            .strip(),
-        }
         if self.analytics_enabled:
+            self.ip_address = utils.get_local_ip_address()
+            data = {
+                "mode": self.mode,
+                "ip_address": self.ip_address,
+                "custom_css": self.css is not None,
+                "theme": self.theme,
+                "version": pkgutil.get_data(__name__, "version.txt")
+                .decode("ascii")
+                .strip(),
+            }
             utils.initiated_analytics(data)
 
     @property
@@ -538,52 +624,6 @@ class Blocks(BlockContext):
 
         return blocks
 
-    def __call__(self, *params, fn_index=0):
-        """
-        Allows Blocks objects to be called as functions
-        Parameters:
-        *params: the parameters to pass to the function
-        fn_index: the index of the function to call (defaults to 0, which for Interfaces, is the default prediction function)
-        """
-        dependency = self.dependencies[fn_index]
-        block_fn = self.fns[fn_index]
-
-        processed_input = []
-        for i, input_id in enumerate(dependency["inputs"]):
-            block = self.blocks[input_id]
-            if getattr(block, "stateful", False):
-                raise ValueError(
-                    "Cannot call Blocks object as a function if any of"
-                    " the inputs are stateful."
-                )
-            else:
-                serialized_input = block.serialize(params[i])
-                processed_input.append(serialized_input)
-
-        processed_input = self.preprocess_data(fn_index, processed_input, None)
-
-        if inspect.iscoroutinefunction(block_fn.fn):
-            predictions = utils.synchronize_async(block_fn.fn, *processed_input)
-        else:
-            predictions = block_fn.fn(*processed_input)
-
-        predictions = self.postprocess_data(fn_index, predictions, None)
-
-        output_copy = copy.deepcopy(predictions)
-        predictions = []
-        for o, output_id in enumerate(dependency["outputs"]):
-            block = self.blocks[output_id]
-            if getattr(block, "stateful", False):
-                raise ValueError(
-                    "Cannot call Blocks object as a function if any of"
-                    " the outputs are stateful."
-                )
-            else:
-                deserialized = block.deserialize(output_copy[o])
-                predictions.append(deserialized)
-
-        return utils.resolve_singleton(predictions)
-
     def __str__(self):
         return self.__repr__()
 
@@ -606,9 +646,19 @@ class Blocks(BlockContext):
 
     def render(self):
         if Context.root_block is not None:
+            if self._id in Context.root_block.blocks:
+                raise DuplicateBlockError(
+                    f"A block with id: {self._id} has already been rendered in the current Blocks."
+                )
+            if not set(Context.root_block.blocks).isdisjoint(self.blocks):
+                raise DuplicateBlockError(
+                    "At least one block in this Blocks has already been rendered."
+                )
+
             Context.root_block.blocks.update(self.blocks)
             Context.root_block.fns.extend(self.fns)
-            for dependency in self.dependencies:
+            dependency_offset = len(Context.root_block.dependencies)
+            for i, dependency in enumerate(self.dependencies):
                 api_name = dependency["api_name"]
                 if api_name is not None:
                     api_name_ = utils.append_unique_suffix(
@@ -622,33 +672,104 @@ class Blocks(BlockContext):
                             )
                         )
                         dependency["api_name"] = api_name_
+                dependency["cancels"] = [
+                    c + dependency_offset for c in dependency["cancels"]
+                ]
+                # Recreate the cancel function so that it has the latest
+                # dependency fn indices. This is necessary to properly cancel
+                # events in the backend
+                if dependency["cancels"]:
+                    updated_cancels = [
+                        Context.root_block.dependencies[i]
+                        for i in dependency["cancels"]
+                    ]
+                    new_fn = BlockFunction(
+                        get_cancel_function(updated_cancels)[0],
+                        [],
+                        [],
+                        False,
+                        True,
+                        False,
+                    )
+                    Context.root_block.fns[dependency_offset + i] = new_fn
                 Context.root_block.dependencies.append(dependency)
             Context.root_block.temp_dirs = Context.root_block.temp_dirs | self.temp_dirs
+
         if Context.block is not None:
             Context.block.children.extend(self.children)
+        return self
 
-    def preprocess_data(self, fn_index, raw_input, state):
+    def is_callable(self, fn_index: int = 0) -> bool:
+        """Checks if a particular Blocks function is callable (i.e. not stateful or a generator)."""
         block_fn = self.fns[fn_index]
         dependency = self.dependencies[fn_index]
 
-        if block_fn.preprocess:
-            processed_input = []
-            for i, input_id in enumerate(dependency["inputs"]):
-                block = self.blocks[input_id]
-                if getattr(block, "stateful", False):
-                    processed_input.append(state.get(input_id))
-                else:
-                    processed_input.append(block.preprocess(raw_input[i]))
-        else:
-            processed_input = raw_input
-        return processed_input
+        if inspect.isasyncgenfunction(block_fn.fn):
+            return False
+        if inspect.isgeneratorfunction(block_fn.fn):
+            raise False
+        for input_id in dependency["inputs"]:
+            block = self.blocks[input_id]
+            if getattr(block, "stateful", False):
+                return False
+        for output_id in dependency["outputs"]:
+            block = self.blocks[output_id]
+            if getattr(block, "stateful", False):
+                return False
 
-    async def call_function(self, fn_index, processed_input, iterator=None):
+        return True
+
+    def __call__(self, *inputs, fn_index: int = 0):
+        """
+        Allows Blocks objects to be called as functions. Supply the parameters to the
+        function as positional arguments. To choose which function to call, use the
+        fn_index parameter, which must be a keyword argument.
+
+        Parameters:
+        *inputs: the parameters to pass to the function
+        fn_index: the index of the function to call (defaults to 0, which for Interfaces, is the default prediction function)
+        """
+        if not (self.is_callable(fn_index)):
+            raise ValueError(
+                "This function is not callable because it is either stateful or is a generator. Please use the .launch() method instead to create an interactive user interface."
+            )
+
+        inputs = list(inputs)
+        processed_inputs = self.serialize_data(fn_index, inputs)
+        batch = self.dependencies[fn_index]["batch"]
+        if batch:
+            processed_inputs = [[inp] for inp in processed_inputs]
+
+        outputs = utils.synchronize_async(self.process_api, fn_index, processed_inputs)
+        outputs = outputs["data"]
+
+        if batch:
+            outputs = [out[0] for out in outputs]
+
+        processed_outputs = self.deserialize_data(fn_index, outputs)
+        processed_outputs = utils.resolve_singleton(processed_outputs)
+
+        return processed_outputs
+
+    async def call_function(
+        self,
+        fn_index: int,
+        processed_input: List[Any],
+        iterator: Iterator[Any] | None = None,
+    ):
         """Calls and times function with given index and preprocessed input."""
         block_fn = self.fns[fn_index]
         is_generating = False
         start = time.time()
 
+        if block_fn.inputs_as_dict:
+            processed_input = [
+                {
+                    input_component: data
+                    for input_component, data in zip(block_fn.inputs, processed_input)
+                }
+            ]
+
         if iterator is None:  # If not a generator function that has already run
             if inspect.iscoroutinefunction(block_fn.fn):
                 prediction = await block_fn.fn(*processed_input)
@@ -665,9 +786,11 @@ class Blocks(BlockContext):
             try:
                 if iterator is None:
                     iterator = prediction
-                prediction = next(iterator)
+                prediction = await anyio.to_thread.run_sync(
+                    utils.async_iteration, iterator, limiter=self.limiter
+                )
                 is_generating = True
-            except StopIteration:
+            except StopAsyncIteration:
                 n_outputs = len(self.dependencies[fn_index].get("outputs"))
                 prediction = (
                     components._Keywords.FINISHED_ITERATING
@@ -685,39 +808,80 @@ class Blocks(BlockContext):
             "iterator": iterator,
         }
 
-    def postprocess_data(self, fn_index, predictions, state):
+    def serialize_data(self, fn_index: int, inputs: List[Any]) -> List[Any]:
+        dependency = self.dependencies[fn_index]
+        processed_input = []
+
+        for i, input_id in enumerate(dependency["inputs"]):
+            block: IOComponent = self.blocks[input_id]
+            serialized_input = block.serialize(inputs[i])
+            processed_input.append(serialized_input)
+
+        return processed_input
+
+    def deserialize_data(self, fn_index: int, outputs: List[Any]) -> List[Any]:
+        dependency = self.dependencies[fn_index]
+        predictions = []
+
+        for o, output_id in enumerate(dependency["outputs"]):
+            block: IOComponent = self.blocks[output_id]
+            deserialized = block.deserialize(outputs[o])
+            predictions.append(deserialized)
+
+        return predictions
+
+    def preprocess_data(self, fn_index: int, inputs: List[Any], state: Dict[int, Any]):
         block_fn = self.fns[fn_index]
         dependency = self.dependencies[fn_index]
 
+        if block_fn.preprocess:
+            processed_input = []
+            for i, input_id in enumerate(dependency["inputs"]):
+                block: IOComponent = self.blocks[input_id]
+                if getattr(block, "stateful", False):
+                    processed_input.append(state.get(input_id))
+                else:
+                    processed_input.append(block.preprocess(inputs[i]))
+        else:
+            processed_input = inputs
+        return processed_input
+
+    def postprocess_data(
+        self, fn_index: int, predictions: List[Any], state: Dict[int, Any]
+    ):
+        block_fn = self.fns[fn_index]
+        dependency = self.dependencies[fn_index]
+        batch = dependency["batch"]
+
         if type(predictions) is dict and len(predictions) > 0:
-            predictions = convert_update_dict_to_list(
+            predictions = convert_component_dict_to_list(
                 dependency["outputs"], predictions
             )
 
-        if len(dependency["outputs"]) == 1:
+        if len(dependency["outputs"]) == 1 and not (batch):
             predictions = (predictions,)
 
-        if block_fn.postprocess:
-            output = []
-            for i, output_id in enumerate(dependency["outputs"]):
-                if predictions[i] is components._Keywords.FINISHED_ITERATING:
-                    output.append(None)
-                    break
-                block = self.blocks[output_id]
-                if getattr(block, "stateful", False):
-                    if not utils.is_update(predictions[i]):
-                        state[output_id] = predictions[i]
-                    output.append(None)
-                else:
-                    prediction_value = predictions[i]
-                    if utils.is_update(prediction_value):
-                        output_value = postprocess_update_dict(block, prediction_value)
-                    else:
-                        output_value = block.postprocess(prediction_value)
-                    output.append(output_value)
-
-        else:
-            output = predictions
+        output = []
+        for i, output_id in enumerate(dependency["outputs"]):
+            if predictions[i] is components._Keywords.FINISHED_ITERATING:
+                output.append(None)
+                continue
+            block = self.blocks[output_id]
+            if getattr(block, "stateful", False):
+                if not utils.is_update(predictions[i]):
+                    state[output_id] = predictions[i]
+                output.append(None)
+            else:
+                prediction_value = predictions[i]
+                if utils.is_update(prediction_value):
+                    prediction_value = postprocess_update_dict(
+                        block=block,
+                        update_dict=prediction_value,
+                        postprocess=block_fn.postprocess,
+                    )
+                elif block_fn.postprocess:
+                    prediction_value = block.postprocess(prediction_value)
+                output.append(prediction_value)
         return output
 
     async def process_api(
@@ -725,33 +889,61 @@ class Blocks(BlockContext):
         fn_index: int,
         inputs: List[Any],
         username: str = None,
-        state: Optional[Dict[int, Any]] = None,
-        iterators: Dict[int, Any] = None,
+        state: Dict[int, Any] | List[Dict[int, Any]] | None = None,
+        iterators: Dict[int, Any] | None = None,
     ) -> Dict[str, Any]:
         """
         Processes API calls from the frontend. First preprocesses the data,
         then runs the relevant function, then postprocesses the output.
         Parameters:
-            data: data recieved from the frontend
-            username: name of user if authentication is set up
-            state: data stored from stateful components for session
+            fn_index: Index of function to run.
+            inputs: input data received from the frontend
+            username: name of user if authentication is set up (not used)
+            state: data stored from stateful components for session (key is input block id)
+            iterators: the in-progress iterators for each generator function (key is function index)
         Returns: None
         """
         block_fn = self.fns[fn_index]
+        batch = self.dependencies[fn_index]["batch"]
 
-        inputs = self.preprocess_data(fn_index, inputs, state)
-        iterator = iterators.get(fn_index, None)
+        if batch:
+            max_batch_size = self.dependencies[fn_index]["max_batch_size"]
+            batch_sizes = [len(inp) for inp in inputs]
+            batch_size = batch_sizes[0]
+            if inspect.isasyncgenfunction(block_fn.fn) or inspect.isgeneratorfunction(
+                block_fn.fn
+            ):
+                raise ValueError("Gradio does not support generators in batch mode.")
+            if not all(x == batch_size for x in batch_sizes):
+                raise ValueError(
+                    f"All inputs to a batch function must have the same length but instead have sizes: {batch_sizes}."
+                )
+            if batch_size > max_batch_size:
+                raise ValueError(
+                    f"Batch size ({batch_size}) exceeds the max_batch_size for this function ({max_batch_size})"
+                )
+
+            inputs = [self.preprocess_data(fn_index, i, state) for i in zip(*inputs)]
+            result = await self.call_function(fn_index, zip(*inputs), None)
+            preds = result["prediction"]
+            data = [self.postprocess_data(fn_index, o, state) for o in zip(*preds)]
+            data = list(zip(*data))
+            is_generating, iterator = None, None
+
+        else:
+            inputs = self.preprocess_data(fn_index, inputs, state)
+            iterator = iterators.get(fn_index, None) if iterators else None
+            result = await self.call_function(fn_index, inputs, iterator)
+            data = self.postprocess_data(fn_index, result["prediction"], state)
+            is_generating, iterator = result["is_generating"], result["iterator"]
 
-        result = await self.call_function(fn_index, inputs, iterator)
         block_fn.total_runtime += result["duration"]
         block_fn.total_runs += 1
 
-        predictions = self.postprocess_data(fn_index, result["prediction"], state)
-
         return {
-            "data": predictions,
-            "is_generating": result["is_generating"],
-            "iterator": result["iterator"],
+            "data": data,
+            "is_generating": is_generating,
+            "iterator": iterator,
             "duration": result["duration"],
             "average_duration": block_fn.total_runtime / block_fn.total_runs,
         }
@@ -842,10 +1034,10 @@ class Blocks(BlockContext):
         method, the two of which, confusingly, do two completely different things.
 
 
-        Class method: loads a demo from a Hugging Face Spaces repo and creates it locally and returns a block instance.
+        Class method: loads a demo from a Hugging Face Spaces repo and creates it locally and returns a block instance. Equivalent to gradio.Interface.load()
 
 
-        Instance method: adds an event for when the demo loads in the browser and returns None.
+        Instance method: adds event that runs as soon as the demo loads in the browser. Example usage below.
         Parameters:
             name: Class Method - the name of the model (e.g. "gpt2"), can include the `src` as prefix (e.g. "models/gpt2")
             src: Class Method - the source of the model: `models` or `spaces` (or empty if source is provided as a prefix in `name`)
@@ -854,6 +1046,15 @@ class Blocks(BlockContext):
             fn: Instance Method - Callable function
             inputs: Instance Method - input list
             outputs: Instance Method - output list
+        Example:
+            import gradio as gr
+            import datetime
+            with gr.Blocks() as demo:
+                def get_time():
+                    return datetime.datetime.now().time()
+                dt = gr.Textbox(label="Current time")
+                demo.load(get_time, inputs=None, outputs=dt)
+            demo.launch()
         """
         # _js: Optional frontend js method to run before running 'fn'. Input arguments for js method are values of 'inputs' and 'outputs', return should be a list of values for output components.
         if isinstance(self_or_cls, type):
@@ -893,6 +1094,7 @@ class Blocks(BlockContext):
         status_update_rate: float | str = "auto",
         client_position_to_load_data: int = 30,
         default_enabled: bool = True,
+        api_open: bool = True,
         max_size: Optional[int] = None,
     ):
         """
@@ -902,18 +1104,22 @@ class Blocks(BlockContext):
             status_update_rate: If "auto", Queue will send status estimations to all clients whenever a job is finished. Otherwise Queue will send status at regular intervals set by this parameter as the number of seconds.
             client_position_to_load_data: Once a client's position in Queue is less that this value, the Queue will collect the input data from the client. You may make this smaller if clients can send large volumes of data, such as video, since the queued data is stored in memory.
             default_enabled: If True, all event listeners will use queueing by default.
+            api_open: If True, the REST routes of the backend will be open, allowing requests made directly to those endpoints to skip the queue.
+            max_size: The maximum number of events the queue will store at any given moment.
         Example:
             demo = gr.Interface(gr.Textbox(), gr.Image(), image_generator)
             demo.queue(concurrency_count=3)
             demo.launch()
         """
         self.enable_queue = default_enabled
+        self.api_open = api_open
         self._queue = queue.Queue(
             live_updates=status_update_rate == "auto",
             concurrency_count=concurrency_count,
             data_gathering_start=client_position_to_load_data,
             update_intervals=status_update_rate if status_update_rate != "auto" else 1,
             max_size=max_size,
+            blocks_dependencies=self.dependencies,
         )
         self.config = self.get_config_file()
         return self
@@ -970,7 +1176,7 @@ class Blocks(BlockContext):
             ssl_certfile: If a path to a file is provided, will use this as the signed certificate for https. Needs to be provided if ssl_keyfile is provided.
             ssl_keyfile_password: If a password is provided, will use this with the ssl certificate for https.
             quiet: If True, suppresses most print statements.
-            show_api: If True, shows the api docs in the footer of the app. Default True.
+            show_api: If True, shows the api docs in the footer of the app. Default True. If the queue is enabled, then api_open parameter of .queue() will determine if the api docs are shown, independent of the value of show_api.
         Returns:
             app: FastAPI app object that is running the demo
             local_url: Locally accessible link to the demo
@@ -997,7 +1203,6 @@ class Blocks(BlockContext):
         self.height = height
         self.width = width
         self.favicon_path = favicon_path
-        self.show_api = show_api
         if enable_queue is not None:
             self.enable_queue = enable_queue
             warnings.warn(
@@ -1011,6 +1216,23 @@ class Blocks(BlockContext):
             self.enable_queue = self.enable_queue is True
         if self.enable_queue and not hasattr(self, "_queue"):
             self.queue()
+        self.show_api = self.api_open if self.enable_queue else show_api
+
+        for dep in self.dependencies:
+            for i in dep["cancels"]:
+                if not self.queue_enabled_for_fn(i):
+                    raise ValueError(
+                        "In order to cancel an event, the queue for that event must be enabled! "
+                        "You may get this error by either 1) passing a function that uses the yield keyword "
+                        "into an interface without enabling the queue or 2) defining an event that cancels "
+                        "another event without enabling the queue. Both can be solved by calling .queue() "
+                        "before .launch()"
+                    )
+            if dep["batch"] and (
+                dep["queue"] is False
+                or (dep["queue"] is None and not self.enable_queue)
+            ):
+                raise ValueError("In order to use batching, the queue must be enabled.")
 
         self.config = self.get_config_file()
         self.share = share
@@ -1136,20 +1358,20 @@ class Blocks(BlockContext):
             except ImportError:
                 pass
 
-        data = {
-            "launch_method": "browser" if inbrowser else "inline",
-            "is_google_colab": is_colab,
-            "is_sharing_on": self.share,
-            "share_url": self.share_url,
-            "ip_address": self.ip_address,
-            "enable_queue": self.enable_queue,
-            "show_tips": self.show_tips,
-            "server_name": server_name,
-            "server_port": server_port,
-            "is_spaces": self.is_space,
-            "mode": self.mode,
-        }
-        if hasattr(self, "analytics_enabled") and self.analytics_enabled:
+        if getattr(self, "analytics_enabled", False):
+            data = {
+                "launch_method": "browser" if inbrowser else "inline",
+                "is_google_colab": is_colab,
+                "is_sharing_on": self.share,
+                "share_url": self.share_url,
+                "ip_address": self.ip_address,
+                "enable_queue": self.enable_queue,
+                "show_tips": self.show_tips,
+                "server_name": server_name,
+                "server_port": server_port,
+                "is_spaces": self.is_space,
+                "mode": self.mode,
+            }
             utils.launch_analytics(data)
 
         utils.show_tip(self)
@@ -1267,3 +1489,8 @@ class Blocks(BlockContext):
         if self.enable_queue:
             utils.run_coro_in_background(self._queue.start)
         utils.run_coro_in_background(self.create_limiter)
+
+    def queue_enabled_for_fn(self, fn_index: int):
+        if self.dependencies[fn_index]["queue"] is None:
+            return self.enable_queue
+        return self.dependencies[fn_index]["queue"]
