@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import base64
 import json
 import mimetypes
@@ -8,6 +10,7 @@ import subprocess
 import tempfile
 import warnings
 from io import BytesIO
+from typing import Dict
 
 import numpy as np
 import requests
@@ -21,9 +24,23 @@ with warnings.catch_warnings():
     from pydub import AudioSegment
 
 
+#########################
+# GENERAL
+#########################
+
+
+def to_binary(x: str | Dict) -> bytes:
+    """Converts a base64 string or dictionary to a binary string that can be sent in a POST."""
+    if isinstance(x, dict):
+        x = encode_url_or_file_to_base64(x["name"])
+    return base64.b64decode(x.split(",")[1])
+
+
 #########################
 # IMAGE PRE-PROCESSING
 #########################
+
+
 def decode_base64_to_image(encoding):
     content = encoding.split(";")[1]
     image_encoded = content.split(",")[1]
@@ -203,32 +220,31 @@ def audio_to_file(sample_rate, data, filename):
 
 def convert_to_16_bit_wav(data):
     # Based on: https://docs.scipy.org/doc/scipy/reference/generated/scipy.io.wavfile.write.html
-    if data.dtype == np.float32:
-        warnings.warn(
-            "Audio data is not in 16-bit integer format."
-            "Trying to convert to 16-bit int format."
-        )
+    warning = "Trying to convert audio automatically from {} to 16-bit int format."
+    if data.dtype in [np.float64, np.float32, np.float16]:
+        warnings.warn(warning.format(data.dtype))
         data = data / np.abs(data).max()
         data = data * 32767
         data = data.astype(np.int16)
     elif data.dtype == np.int32:
-        warnings.warn(
-            "Audio data is not in 16-bit integer format."
-            "Trying to convert to 16-bit int format."
-        )
+        warnings.warn(warning.format(data.dtype))
         data = data / 65538
         data = data.astype(np.int16)
     elif data.dtype == np.int16:
         pass
+    elif data.dtype == np.uint16:
+        warnings.warn(warning.format(data.dtype))
+        data = data - 32768
+        data = data.astype(np.int16)
     elif data.dtype == np.uint8:
-        warnings.warn(
-            "Audio data is not in 16-bit integer format."
-            "Trying to convert to 16-bit int format."
-        )
+        warnings.warn(warning.format(data.dtype))
         data = data * 257 - 32768
         data = data.astype(np.int16)
     else:
-        raise ValueError("Audio data cannot be converted to " "16-bit int format.")
+        raise ValueError(
+            "Audio data cannot be converted automatically from "
+            f"{data.dtype} to 16-bit int format."
+        )
     return data
 
 
@@ -312,6 +328,7 @@ def create_tmp_copy_of_file(file_path, dir=None):
     if "." in file_name:
         prefix = file_name[0 : file_name.index(".")]
         extension = file_name[file_name.index(".") + 1 :]
+    prefix = utils.strip_invalid_filename_characters(prefix)
     if extension is None:
         file_obj = tempfile.NamedTemporaryFile(delete=False, prefix=prefix, dir=dir)
     else:
