@@ -1,12 +1,10 @@
-import gradio
-
 XRAY_CONFIG = {
-    "version": "3.1.8b\n",
+    "version": "3.4b3\n",
     "mode": "blocks",
     "dev_mode": True,
     "components": [
         {
-            "id": 23,
+            "id": 27,
             "type": "markdown",
             "props": {
                 "value": "<h1>Detect Disease From Scan</h1>\n<p>With this model you can lorem ipsum</p>\n<ul>\n<li>ipsum 1</li>\n<li>ipsum 2</li>\n</ul>\n",
@@ -16,7 +14,7 @@ XRAY_CONFIG = {
             },
         },
         {
-            "id": 24,
+            "id": 28,
             "type": "checkboxgroup",
             "props": {
                 "choices": ["Covid", "Malaria", "Lung Cancer"],
@@ -28,19 +26,24 @@ XRAY_CONFIG = {
                 "style": {},
             },
         },
-        {"id": 25, "type": "tabs", "props": {"visible": True, "style": {}}},
+        {"id": 29, "type": "tabs", "props": {"visible": True, "style": {}}},
         {
-            "id": 26,
+            "id": 30,
             "type": "tabitem",
             "props": {"label": "X-ray", "visible": True, "style": {}},
         },
         {
-            "id": 27,
+            "id": 31,
             "type": "row",
-            "props": {"type": "row", "visible": True, "style": {}},
+            "props": {
+                "type": "row",
+                "variant": "default",
+                "visible": True,
+                "style": {},
+            },
         },
         {
-            "id": 28,
+            "id": 32,
             "type": "image",
             "props": {
                 "image_mode": "RGB",
@@ -55,17 +58,12 @@ XRAY_CONFIG = {
             },
         },
         {
-            "id": 29,
+            "id": 33,
             "type": "json",
-            "props": {
-                "show_label": True,
-                "name": "json",
-                "visible": True,
-                "style": {},
-            },
+            "props": {"show_label": True, "name": "json", "visible": True, "style": {}},
         },
         {
-            "id": 30,
+            "id": 34,
             "type": "button",
             "props": {
                 "value": "Run",
@@ -75,43 +73,43 @@ XRAY_CONFIG = {
                 "style": {},
             },
         },
-        {
-            "id": 31,
-            "type": "tabitem",
-            "props": {"label": "CT Scan", "visible": True, "style": {}},
-        },
-        {
-            "id": 32,
-            "type": "row",
-            "props": {"type": "row", "visible": True, "style": {}},
-        },
-        {
-            "id": 33,
-            "type": "image",
-            "props": {
-                "image_mode": "RGB",
-                "source": "upload",
-                "tool": "editor",
-                "streaming": False,
-                "mirror_webcam": True,
-                "show_label": True,
-                "name": "image",
-                "visible": True,
-                "style": {},
-            },
-        },
-        {
-            "id": 34,
-            "type": "json",
-            "props": {
-                "show_label": True,
-                "name": "json",
-                "visible": True,
-                "style": {},
-            },
-        },
         {
             "id": 35,
+            "type": "tabitem",
+            "props": {"label": "CT Scan", "visible": True, "style": {}},
+        },
+        {
+            "id": 36,
+            "type": "row",
+            "props": {
+                "type": "row",
+                "variant": "default",
+                "visible": True,
+                "style": {},
+            },
+        },
+        {
+            "id": 37,
+            "type": "image",
+            "props": {
+                "image_mode": "RGB",
+                "source": "upload",
+                "tool": "editor",
+                "streaming": False,
+                "mirror_webcam": True,
+                "show_label": True,
+                "name": "image",
+                "visible": True,
+                "style": {},
+            },
+        },
+        {
+            "id": 38,
+            "type": "json",
+            "props": {"show_label": True, "name": "json", "visible": True, "style": {}},
+        },
+        {
+            "id": 39,
             "type": "button",
             "props": {
                 "value": "Run",
@@ -122,7 +120,7 @@ XRAY_CONFIG = {
             },
         },
         {
-            "id": 36,
+            "id": 40,
             "type": "textbox",
             "props": {
                 "lines": 1,
@@ -135,12 +133,12 @@ XRAY_CONFIG = {
             },
         },
         {
-            "id": 37,
+            "id": 41,
             "type": "form",
             "props": {"type": "form", "visible": True, "style": {}},
         },
         {
-            "id": 38,
+            "id": 42,
             "type": "form",
             "props": {"type": "form", "visible": True, "style": {}},
         },
@@ -151,79 +149,91 @@ XRAY_CONFIG = {
     "is_space": False,
     "enable_queue": None,
     "show_error": False,
+    "show_api": True,
     "layout": {
-        "id": 22,
+        "id": 26,
         "children": [
-            {"id": 23},
-            {"id": 37, "children": [{"id": 24}]},
+            {"id": 27},
+            {"id": 41, "children": [{"id": 28}]},
             {
-                "id": 25,
+                "id": 29,
                 "children": [
                     {
-                        "id": 26,
+                        "id": 30,
                         "children": [
-                            {"id": 27, "children": [{"id": 28}, {"id": 29}]},
-                            {"id": 30},
+                            {"id": 31, "children": [{"id": 32}, {"id": 33}]},
+                            {"id": 34},
                         ],
                     },
                     {
-                        "id": 31,
+                        "id": 35,
                         "children": [
-                            {"id": 32, "children": [{"id": 33}, {"id": 34}]},
-                            {"id": 35},
+                            {"id": 36, "children": [{"id": 37}, {"id": 38}]},
+                            {"id": 39},
                         ],
                     },
                 ],
             },
-            {"id": 38, "children": [{"id": 36}]},
+            {"id": 42, "children": [{"id": 40}]},
         ],
     },
     "dependencies": [
         {
-            "targets": [30],
+            "targets": [34],
             "trigger": "click",
-            "inputs": [24, 28],
-            "outputs": [29],
+            "inputs": [28, 32],
+            "outputs": [33],
             "backend_fn": True,
             "js": None,
             "queue": None,
             "api_name": None,
             "scroll_to_output": False,
             "show_progress": True,
+            "batch": False,
+            "max_batch_size": 4,
+            "cancels": [],
         },
         {
-            "targets": [35],
+            "targets": [39],
             "trigger": "click",
-            "inputs": [24, 33],
-            "outputs": [34],
+            "inputs": [28, 37],
+            "outputs": [38],
             "backend_fn": True,
             "js": None,
             "queue": None,
             "api_name": None,
             "scroll_to_output": False,
             "show_progress": True,
+            "batch": False,
+            "max_batch_size": 4,
+            "cancels": [],
         },
         {
             "targets": [],
             "trigger": "load",
             "inputs": [],
-            "outputs": [36],
+            "outputs": [40],
             "backend_fn": True,
             "js": None,
             "queue": None,
             "api_name": None,
             "scroll_to_output": False,
             "show_progress": True,
+            "batch": False,
+            "max_batch_size": 4,
+            "cancels": [],
         },
     ],
 }
 
+
 XRAY_CONFIG_DIFF_IDS = {
+    "version": "3.4b3\n",
     "mode": "blocks",
     "dev_mode": True,
     "components": [
         {
-            "id": 1,
+            "id": 27,
             "type": "markdown",
             "props": {
                 "value": "<h1>Detect Disease From Scan</h1>\n<p>With this model you can lorem ipsum</p>\n<ul>\n<li>ipsum 1</li>\n<li>ipsum 2</li>\n</ul>\n",
@@ -233,7 +243,7 @@ XRAY_CONFIG_DIFF_IDS = {
             },
         },
         {
-            "id": 22,
+            "id": 28,
             "type": "checkboxgroup",
             "props": {
                 "choices": ["Covid", "Malaria", "Lung Cancer"],
@@ -245,30 +255,24 @@ XRAY_CONFIG_DIFF_IDS = {
                 "style": {},
             },
         },
+        {"id": 29, "type": "tabs", "props": {"visible": True, "style": {}}},
         {
-            "id": 3,
-            "type": "tabs",
-            "props": {
-                "visible": True,
-                "style": {},
-            },
-        },
-        {
-            "id": 444,
+            "id": 30,
             "type": "tabitem",
+            "props": {"label": "X-ray", "visible": True, "style": {}},
+        },
+        {
+            "id": 31,
+            "type": "row",
             "props": {
-                "label": "X-ray",
+                "type": "row",
+                "variant": "default",
                 "visible": True,
                 "style": {},
             },
         },
         {
-            "id": 5,
-            "type": "row",
-            "props": {"type": "row", "visible": True, "style": {}},
-        },
-        {
-            "id": 6,
+            "id": 32,
             "type": "image",
             "props": {
                 "image_mode": "RGB",
@@ -283,17 +287,12 @@ XRAY_CONFIG_DIFF_IDS = {
             },
         },
         {
-            "id": 7,
+            "id": 33,
             "type": "json",
-            "props": {
-                "show_label": True,
-                "name": "json",
-                "visible": True,
-                "style": {},
-            },
+            "props": {"show_label": True, "name": "json", "visible": True, "style": {}},
         },
         {
-            "id": 8888,
+            "id": 34,
             "type": "button",
             "props": {
                 "value": "Run",
@@ -304,21 +303,22 @@ XRAY_CONFIG_DIFF_IDS = {
             },
         },
         {
-            "id": 9,
+            "id": 35,
             "type": "tabitem",
+            "props": {"label": "CT Scan", "visible": True, "style": {}},
+        },
+        {
+            "id": 36,
+            "type": "row",
             "props": {
-                "label": "CT Scan",
+                "type": "row",
+                "variant": "default",
                 "visible": True,
                 "style": {},
             },
         },
         {
-            "id": 10,
-            "type": "row",
-            "props": {"type": "row", "visible": True, "style": {}},
-        },
-        {
-            "id": 11,
+            "id": 37,
             "type": "image",
             "props": {
                 "image_mode": "RGB",
@@ -333,17 +333,12 @@ XRAY_CONFIG_DIFF_IDS = {
             },
         },
         {
-            "id": 12,
+            "id": 38,
             "type": "json",
-            "props": {
-                "show_label": True,
-                "name": "json",
-                "visible": True,
-                "style": {},
-            },
+            "props": {"show_label": True, "name": "json", "visible": True, "style": {}},
         },
         {
-            "id": 13,
+            "id": 933,
             "type": "button",
             "props": {
                 "value": "Run",
@@ -354,7 +349,7 @@ XRAY_CONFIG_DIFF_IDS = {
             },
         },
         {
-            "id": 141,
+            "id": 40,
             "type": "textbox",
             "props": {
                 "lines": 1,
@@ -367,86 +362,100 @@ XRAY_CONFIG_DIFF_IDS = {
             },
         },
         {
-            "id": 37,
+            "id": 41,
             "type": "form",
             "props": {"type": "form", "visible": True, "style": {}},
         },
         {
-            "id": 38,
+            "id": 42,
             "type": "form",
             "props": {"type": "form", "visible": True, "style": {}},
         },
     ],
     "theme": "default",
     "css": None,
-    "enable_queue": False,
+    "title": "Gradio",
+    "is_space": False,
+    "enable_queue": None,
+    "show_error": False,
+    "show_api": True,
     "layout": {
-        "id": 0,
+        "id": 26,
         "children": [
-            {"id": 1},
-            {"id": 37, "children": [{"id": 22}]},
+            {"id": 27},
+            {"id": 41, "children": [{"id": 28}]},
             {
-                "id": 3,
+                "id": 29,
                 "children": [
                     {
-                        "id": 444,
+                        "id": 30,
                         "children": [
-                            {"id": 5, "children": [{"id": 6}, {"id": 7}]},
-                            {"id": 8888},
+                            {"id": 31, "children": [{"id": 32}, {"id": 33}]},
+                            {"id": 34},
                         ],
                     },
                     {
-                        "id": 9,
+                        "id": 35,
                         "children": [
-                            {"id": 10, "children": [{"id": 11}, {"id": 12}]},
-                            {"id": 13},
+                            {"id": 36, "children": [{"id": 37}, {"id": 38}]},
+                            {"id": 933},
                         ],
                     },
                 ],
             },
-            {"id": 38, "children": [{"id": 141}]},
+            {"id": 42, "children": [{"id": 40}]},
         ],
     },
     "dependencies": [
         {
-            "targets": [8888],
+            "targets": [34],
             "trigger": "click",
-            "inputs": [22, 6],
-            "outputs": [7],
+            "inputs": [28, 32],
+            "outputs": [33],
             "backend_fn": True,
             "js": None,
             "queue": None,
             "api_name": None,
             "scroll_to_output": False,
             "show_progress": True,
+            "batch": False,
+            "max_batch_size": 4,
+            "cancels": [],
         },
         {
-            "targets": [13],
+            "targets": [933],
             "trigger": "click",
-            "inputs": [22, 11],
-            "outputs": [12],
+            "inputs": [28, 37],
+            "outputs": [38],
             "backend_fn": True,
             "js": None,
             "queue": None,
             "api_name": None,
             "scroll_to_output": False,
             "show_progress": True,
+            "batch": False,
+            "max_batch_size": 4,
+            "cancels": [],
         },
         {
             "targets": [],
             "trigger": "load",
             "inputs": [],
-            "outputs": [141],
+            "outputs": [40],
             "backend_fn": True,
             "js": None,
             "queue": None,
             "api_name": None,
             "scroll_to_output": False,
             "show_progress": True,
+            "batch": False,
+            "max_batch_size": 4,
+            "cancels": [],
         },
     ],
 }
 
+
 XRAY_CONFIG_WITH_MISTAKE = {
     "mode": "blocks",
     "dev_mode": True,
@@ -492,7 +501,7 @@ XRAY_CONFIG_WITH_MISTAKE = {
         {
             "id": 5,
             "type": "row",
-            "props": {"type": "row", "style": {}, "value": True},
+            "props": {"type": "row", "variant": "default", "style": {}, "value": True},
         },
         {
             "id": 6,
@@ -538,7 +547,7 @@ XRAY_CONFIG_WITH_MISTAKE = {
         {
             "id": 10,
             "type": "row",
-            "props": {"type": "row", "style": {}, "value": True},
+            "props": {"type": "row", "variant": "default", "style": {}, "value": True},
         },
         {
             "id": 11,
@@ -619,6 +628,7 @@ XRAY_CONFIG_WITH_MISTAKE = {
             "api_name": None,
             "scroll_to_output": False,
             "show_progress": True,
+            "cancels": [],
         },
         {
             "targets": [13],
@@ -628,6 +638,7 @@ XRAY_CONFIG_WITH_MISTAKE = {
             "api_name": None,
             "scroll_to_output": False,
             "show_progress": True,
+            "cancels": [],
         },
     ],
 }
