@@ -10,6 +10,7 @@ import json.decoder
 import os
 import pkgutil
 import random
+import sys
 import warnings
 from contextlib import contextmanager
 from distutils.version import StrictVersion
@@ -29,13 +30,13 @@ from typing import (
 )
 
 import aiohttp
-import analytics
 import fsspec.asyn
 import httpx
 import requests
 from pydantic import BaseModel, Json, parse_obj_as
 
 import gradio
+from gradio.context import Context
 
 if TYPE_CHECKING:  # Only import for type checking (is False at runtime).
     from gradio.blocks import BlockContext
@@ -43,7 +44,6 @@ if TYPE_CHECKING:  # Only import for type checking (is False at runtime).
 
 analytics_url = "https://api.gradio.app/"
 PKG_VERSION_URL = "https://api.gradio.app/pkg-version"
-analytics.write_key = "uxIFddIEuuUcFLf9VgH2teTEtPlWdkNy"
 JSON_PATH = os.path.join(os.path.dirname(gradio.__file__), "launches.json")
 
 
@@ -386,6 +386,14 @@ def run_coro_in_background(func: Callable, *args, **kwargs):
     return event_loop.create_task(func(*args, **kwargs))
 
 
+def async_iteration(iterator):
+    try:
+        return next(iterator)
+    except StopIteration:
+        # raise a ValueError here because co-routines can't raise StopIteration themselves
+        raise StopAsyncIteration()
+
+
 class Request:
     """
     The Request class is a low-level API that allow you to create asynchronous HTTP requests without a context manager.
@@ -679,3 +687,66 @@ def validate_url(possible_url: str) -> bool:
 
 def is_update(val):
     return type(val) is dict and "update" in val.get("__type__", "")
+
+
+def check_function_inputs_match(fn: Callable, inputs: List, inputs_as_dict: bool):
+    """
+    Checks if the input component set matches the function
+    Returns: None if valid, a string error message if mismatch
+    """
+    signature = inspect.signature(fn)
+    min_args = 0
+    max_args = 0
+    for param in signature.parameters.values():
+        has_default = param.default != param.empty
+        if param.kind in [param.POSITIONAL_ONLY, param.POSITIONAL_OR_KEYWORD]:
+            if not has_default:
+                min_args += 1
+            max_args += 1
+        elif param.kind == param.VAR_POSITIONAL:
+            max_args = "infinity"
+        elif param.kind == param.KEYWORD_ONLY:
+            if not has_default:
+                return f"Keyword-only args must have default values for function {fn}"
+    arg_count = 1 if inputs_as_dict else len(inputs)
+    if min_args == max_args and max_args != arg_count:
+        warnings.warn(
+            f"Expected {max_args} arguments for function {fn}, received {arg_count}."
+        )
+    if arg_count < min_args:
+        warnings.warn(
+            f"Expected at least {min_args} arguments for function {fn}, received {arg_count}."
+        )
+    if max_args != "infinity" and arg_count > max_args:
+        warnings.warn(
+            f"Expected maximum {max_args} arguments for function {fn}, received {arg_count}."
+        )
+
+
+def get_cancel_function(
+    dependencies: List[Dict[str, Any]]
+) -> Tuple[Callable, List[int]]:
+    fn_to_comp = {}
+    for dep in dependencies:
+        fn_index = next(
+            i for i, d in enumerate(Context.root_block.dependencies) if d == dep
+        )
+        fn_to_comp[fn_index] = [Context.root_block.blocks[o] for o in dep["outputs"]]
+
+    async def cancel(session_hash: str) -> None:
+        if sys.version_info < (3, 8):
+            return None
+
+        task_ids = set([f"{session_hash}_{fn}" for fn in fn_to_comp])
+
+        matching_tasks = [
+            task for task in asyncio.all_tasks() if task.get_name() in task_ids
+        ]
+        for task in matching_tasks:
+            task.cancel()
+        await asyncio.gather(*matching_tasks, return_exceptions=True)
+
+    return (
+        cancel,
+        list(fn_to_comp.keys()),
+    )
